 function rydd(filename) 

%{
.............................................................

Script for evaluating data from backflushing experiments conducted at the
hydraulic laboratory at NTNU, spring 2012.

The script reads the .csv data output from the measurement manager. It is
written to evaluate the rack adhesion using the PEETRA system, and the
operator should enter mean adhesion and 70%pred.intervall range. (mean
value +- the 70pred.int value)

The plotting scripts are using ghostscript and xpdf, that can be downloaded
for free on the web. The export-fig commands can be commented out, and
normal print- or plot functions can be used.

Do not hesitate to contact the writer if for the use of the scripts. They
have not been written with a 3rd pary user in mind. Unfortunatly, the
comments are only in Norwegian.

---------------June 2012, Lars Eid Nielsen----------------------
%}


[NUM,TXT]=xlsread(filename);
                            
fnr=input('Forsk nr: ')      ;                   
heft=input('Netto heft [N]: ');
stdf=input('Std. feil, 70% pred.int.:');

sigma=heft/133.5;
sigmaSE=stdf/133.4;

dato=TXT(4,3);    

freq=NUM(11,2);             %loggefrekvens i Hz
loggstart=10;               %antal sekunder etter start video logging starter
spylestart=40; 

if fnr==6 || fnr==7         %justerer mlinger med drlig spyling
    spylestart=41.5;        
end
if fnr==8
    spylestart=40.5;
end

%antal sekunder etter start video spyling starter
timelag=2;                  %forsinkelse fra start logging til programvaren faktisk starter  logge
spyletid=18;                %tid for pning av spyleventil
extratime=0;                %antall sekunder som skal inkluderes i kurvetilpasning fra fr spylingen.
n=size(NUM(:,1));           %antal rader i rdata

polydeg=15;                 %grad for tilpasset polynom
avgnum=15;

P=zeros(n-31,4);            %oppretter tom matrise for trykkdata
t=zeros(n-32,1);            %tidsvektor
trykkdiff=zeros(n-31,1);    %P3-P2

for i=1:n-31
                                          %-t er tid fra rdata, -T er
                                           %justert tid for spyling
                                           
    t(i)=NUM(i+31,1)/freq;                %Skriver tidsvektor i [s] fra start spyling

        for j=1:4
            P(i,j)=NUM(i+31,j+1)*100/9.81;     %Skriver trykkmatrise i mVS
        end
    trykkdiff(i)=P(i,3)-P(i,2);                %Vektor for trykkforskjell P3-P2 [mVS]   
end

m=(spyletid+extratime)*freq;    %antal mlinger i spyleutvalg
delay=spylestart-loggstart-timelag-extratime;

T=zeros(m,1);                   %matrise for sorterte spyledata.
P4r=zeros(m,1);                 %PF for spylingen
v=zeros(m,1);
P32=zeros(m,1);

for i=1:m
    T(i)=i/freq-extratime;
    P4r(i)=P(i+delay*freq,4);
    P32(i)=P(i+delay*freq,3)-P(i+delay*freq,2);
end

[p]=polyfit(T,P4r,polydeg);   %Tilpasser polynom av grad 'polydeg' til P4
k=polyder(p);                   %deriverer polynomet
f=polyval(p,T);                 %regner ut funksjonsverdier for f
df=polyval(k,T);                %regner ut funksjonsverdier for df
R=corrcoef(P4r,f);
r2=R(1,2);

for i=1:m
    v(i)=-df(i)*(0.7*0.71)/(0.35^2);    %Regner ut hastighet i kanalen
end

dp=smooth(P32,avgnum);
h=plotp32(T,[P32,dp],fnr);                                  %se plotp32.m
set(gcf, 'Color', 'w');
export_fig p32_vektor.eps -painters
%print(h, '-depsc',['figurer/' num2str(fnr) '_P3-P2(t)']);%printer plot til fil

[maxdiff,slipp]=max(dp(15:m-15));                       %lagrer max(P3-P2) og cellerad for slipp

h=plotp4(T,[P4r,f],fnr,polydeg,r2);                                    %se plotp4.m
set(gcf, 'Color', 'w');
export_fig p4plot_vektor.eps -painters
%print(h, '-depsc',['figurer/' num2str(fnr) '_P4(t)']);   %printer plot til fil

h=plotv(T,v,fnr,polydeg);                                           %se plotv.m                  
set(gcf, 'Color', 'w');
export_fig vplot_vektor.eps -painters
%print(h, '-depsc',['figurer/' num2str(fnr) '_V(t)']);   %printer plot til fil

Vslipp=v(slipp);                                         %V ved slipp
Tslipp=T(slipp);                                         %T ved slipp

h=plotpv(T,[P32,dp],v,fnr,sigma,sigmaSE,maxdiff,Tslipp,Vslipp);
set(gcf, 'Color', 'w');
export_fig pvplot_vektor.eps -painters
%print(h,'-depsc',['figurer/pvplot/' num2str(fnr) '_pv']);

string=[fnr,dato,freq,heft,stdf,Tslipp,maxdiff,Vslipp,r2,polydeg,sigma,sigmaSE];   
NUM=xlsread('forskslogg.xlsx');
newrow=size(NUM,1)+2;
xlswrite('forskslogg.xlsx',string,'Sheet1',['A' num2str(newrow)]); %skriver i xls-fila p frste ledige rad
NUM(newrow-1,:)=[fnr,0,freq,heft,stdf,Tslipp,maxdiff,Vslipp,r2,polydeg,sigma,sigmaSE];       %oppdaterer NUM for  plotte
logg=NUM  ;                                                         %lagrer forskslogg i variablen logg

figure
%scatter(NUM(:,11),NUM(:,8),[],[0 0 0]);  %Plotter samlegraf




xlim([0.0 0.3]);
ylim([0 0.2]);
% Create xlabel
xlabel({'Trash rack adhesion [mWC] , 70% pred.int'});

% Create ylabel
ylabel({'Channel velocity at release [m/s]'});

hold all
h=herrorbar(NUM(:,11),NUM(:,8),NUM(:,12),NUM(:,12),'+');
set(h,'Color','Black');
for k = 1:size(NUM,1)                                      % Adding labels
  text(NUM(k,11),NUM(k,8)+0.004,num2str(NUM(k,1)))
end
set(gcf, 'Color', 'w');
export_fig v_release_vektor.eps -painters

%-------------max p plot-----------------------

h=maxp(NUM(:,11),NUM(:,7),NUM(:,12),NUM(:,1));
set(gcf, 'Color', 'w');
export_fig pmax_vektor.eps -painters
%print(h, '-depsc',['figurer/maxp/' num2str(fnr) '_maxp']);




%----------------------------Pressure development plot----------------

NUM=xlsread('samleplotA.xlsx','Sheet1');
dim=size(NUM);
NUM(1,dim(2)+1)=fnr;                           %legger inn ny overskrift ledig kolonne
NUM(2:size(dp)+1,dim(2)+1)=dp;                          %skriver P3-P2
xlswrite('samleplotA.xlsx',NUM,'Sheet1');

colormap(jet);
cm=colormap;
%cm=flipdim(cm,1);

stappmin=0.09;
stappmax=0.25;
stapprange=stappmax-stappmin;


figure1=figure('colormap',cm);

axes1 = axes('Parent',figure1,'CLim',[0.09 0.25],...
    'XMinorTicks','on','YMinorTicks','on');
xlim([0,15]);
ylim([-0.01,0.12]);
box(axes1,'on');
hold(axes1,'all');

for i=1:size(NUM,2);
    pnr=NUM(1,i);
    for j=1:size(logg,1);
        if logg(j,1)==pnr
            stapp=logg(j,11);
        end
    end
    
    colornum=ceil((stapp-stappmin)/stapprange*(size(cm,1)-1))+1;
    col=cm(colornum,:);
    h=plot(T,NUM(2:size(dp)+1,i),'Color',col);
    set(h,'LineWidth',1);
    
hold on
end

colorbar('peer',axes1,'location','EastOutside','CLim',[0.09 0.25]);
    
% Create xlabel
xlabel({'Time [s]'});

% Create ylabel
ylabel({'Pressure difference  [mWC]'});


% Create textbox
%annotation(figure1,'textarrow',[0 0 0 0],'String',{'Debris Adhesion  [N]'},'HeadStyle','none','LineStyle', 'none', 'TextRotation',90);

annotation(figure1,'textarrow',[0.890199335548172 0.82],...
    [0.36042477659445 0.380462724935732],'TextEdgeColor','none',...
    'String',{'Trash rack adhesion  [mWC]'},...
    'HeadStyle','none',...
    'LineStyle','none','TextRotation',270);
set(gcf, 'Color', 'w');
export_fig samleplot_dp_vektor.eps -painters

%-----------Sammenligning av spyling-----------------------------

%{
  NUM=xlsread('hastighet.xlsx','Sheet1');
dim=size(NUM);
NUM(1,dim(2)+1)=fnr;                           %legger inn ny overskrift ledig kolonne
NUM(2:size(v)+1,dim(2)+1)=v;                          %skriver v(t)
xlswrite('hastighet.xlsx',NUM,'Sheet1');

h=vtest(NUM,dp,T);
set(gcf, 'Color', 'w');
export_fig pmax_vektor.eps -painters
%print(h, '-djpeg','figurer/spyletest/spyletest');   %printer plot til fil

%}